==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Statistics/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_HITS","Hits");
define("_BROWSERS","Browser");
define("_OPERATINGSYS","Betriebssystem");
define("_UNKNOWN","Unbekannt");
define("_OTHER","Andere / Unbekannt");
define("_MISCSTATS","Verschiedene Statistiken");
define("_REGUSERS","angemeldete Benutzer:");
define("_ACTIVEAUTHORS","Aktive Autoren:");
define("_STORIESPUBLISHED","Artikel:");
define("_SACTIVETOPICS","Aktive Themen:");
define("_COMMENTSPOSTED","Kommentare:");
define("_SSPECIALSECT","Themen:");
define("_ARTICLESSEC","Artikel in Bereichen:");
define("_LINKSINLINKS","Links in WebLinks:");
define("_LINKSCAT","WebLinks- Kategorien:");
define("_NEWSWAITING","Nachrichten, die auf Best&auml;tigung warten:");
define("_NUKEVERSION","PHP-Nuke Version:");
define("_SEARCHENGINES","Suchmaschinen");
define("_BOTS","Bots / Spider");
define("_STATS","Statistiken");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Statistics/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_HITS","Hits");
define("_BROWSERS","Browser");
define("_OPERATINGSYS","Betriebssystem");
define("_UNKNOWN","Unbekannt");
define("_OTHER","Andere / Unbekannt");
define("_MISCSTATS","Verschiedene Statistiken");
define("_REGUSERS","angemeldete Benutzer:");
define("_ACTIVEAUTHORS","Aktive Autoren:");
define("_STORIESPUBLISHED","Artikel:");
define("_SACTIVETOPICS","Aktive Themen:");
define("_COMMENTSPOSTED","Kommentare:");
define("_SSPECIALSECT","Themen:");
define("_ARTICLESSEC","Artikel in Bereichen:");
define("_LINKSINLINKS","Links in WebLinks:");
define("_LINKSCAT","WebLinks- Kategorien:");
define("_NEWSWAITING","Nachrichten, die auf Best&auml;tigung warten:");
define("_NUKEVERSION","PHP-Nuke Version:");
define("_SEARCHENGINES","Suchmaschinen");
define("_BOTS","Bots / Spider");
define("_STATS","Statistiken");
define("_RETURNBASICSTATS","Return to Basic Statistics");
define("_BACKTODETSTATS","Back to Detailed Statistics");
define("_BACKTOMAIN","Back to Main");
define("_TODAYIS","Today is");
define("_MOSTMONTH","Busiest Month");
define("_MOSTDAY","Busiest Day");
define("_MOSTHOUR","Busiest Hour");
define("_YEARLYSTATS","Yearly Stats");
define("_MONTLYSTATS","Montly Stats for");
define("_SPAGESVIEWS","Page Views");
define("_DAILYSTATS","Daily Stats for");
define("_HOURLYSTATS","Hourly Stats for");

?>
